@@ -4,15 +4,16 @@ use crate::{max, min, FuturesTypes, Order, Side};
 pub(crate) fn order_margin<'a>(
     orders: impl Iterator<Item = &'a Order>,
     pos_size: f64,
-    pos_entry_price: f64,
     futures_type: FuturesTypes,
     leverage: f64,
     fee_maker: f64,
 ) -> f64 {
     let mut buy_size: f64 = 0.0;
     let mut sell_size: f64 = 0.0;
-    let mut max_buy_price: f64 = 0.0;
-    let mut min_sell_price: f64 = 0.0;
+    let mut buy_price_sum: f64 = 0.0;
+    let mut sell_price_sum: f64 = 0.0;
+    let mut num_buy_orders: f64 = 0.0;
+    let mut num_sell_orders: f64 = 0.0;
     let mut cumulative_fees: f64 = 0.0;
     for o in orders {
         let price = o.limit_price().unwrap();
@@ -20,24 +21,16 @@ pub(crate) fn order_margin<'a>(
             FuturesTypes::Linear => price,
             FuturesTypes::Inverse => 1.0 / price,
         };
-        if max_buy_price == 0.0 {
-            max_buy_price = price;
-        }
-        if min_sell_price == 0.0 {
-            min_sell_price = price;
-        }
         match o.side() {
             Side::Buy => {
                 buy_size += o.size();
-                if price > max_buy_price {
-                    max_buy_price = price;
-                }
+                buy_price_sum += o.limit_price().unwrap();
+                num_buy_orders += 1.0;
             }
             Side::Sell => {
                 sell_size += o.size();
-                if price < min_sell_price {
-                    min_sell_price = price;
-                }
+                sell_price_sum += o.limit_price().unwrap();
+                num_sell_orders += 1.0;
             }
         }
         cumulative_fees += o.size() * price_mult * fee_maker;
@@ -47,22 +40,24 @@ pub(crate) fn order_margin<'a>(
     let ssd = sell_size - max(pos_size, 0.0);
     let order_margin: f64 = if buy_size == 0.0 && sell_size == 0.0 {
         0.0
+    } else if bsd == 0.0 && ssd == 0.0 {
+        0.0
     } else if ssd > bsd {
         let price_mult = match futures_type {
-            FuturesTypes::Linear => min_sell_price,
-            FuturesTypes::Inverse => 1.0 / min_sell_price,
+            FuturesTypes::Linear => (sell_price_sum / max(num_sell_orders, 1.0)),
+            FuturesTypes::Inverse => 1.0 / (sell_price_sum / max(num_sell_orders, 1.0)),
         };
         ssd * price_mult
     } else {
         let price_mult = match futures_type {
-            FuturesTypes::Linear => max_buy_price,
-            FuturesTypes::Inverse => 1.0 / max_buy_price,
+            FuturesTypes::Linear => (buy_price_sum / max(num_buy_orders, 1.0)),
+            FuturesTypes::Inverse => 1.0 / (buy_price_sum / max(num_buy_orders, 1.0)),
         };
         bsd * price_mult
     };
     debug!(
-        "bsd: {}, ssd: {}, max_buy_price: {}, min_sell_price: {}, om: {}",
-        bsd, ssd, max_buy_price, min_sell_price, order_margin
+        "bsd: {}, ssd: {}, buy_price_sum: {}, sell_price_sum: {}, om: {}, fees: {}",
+        bsd, ssd, buy_price_sum, sell_price_sum, order_margin, cumulative_fees,
     );
 
     // TODO: not sure if this method of including the fees is correct, but its about right xD
@@ -79,66 +74,65 @@ mod tests {
 
         let ft = FuturesTypes::Linear;
         let p = 0.0;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 300.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 300.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
         }
     }
 
@@ -147,7 +141,6 @@ mod tests {
         if let Err(_) = pretty_env_logger::try_init() {}
 
         let ft = FuturesTypes::Linear;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
@@ -156,66 +149,66 @@ mod tests {
             debug!("leverage: {}", l);
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 300.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 300.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
         }
     }
 
@@ -224,7 +217,6 @@ mod tests {
         if let Err(_) = pretty_env_logger::try_init() {}
 
         let ft = FuturesTypes::Linear;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
@@ -233,66 +225,66 @@ mod tests {
             debug!("leverage: {}", l);
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 100.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 100.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 200.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 200.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 300.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 300.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 1.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 1.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 150.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 150.0);
         }
     }
 
@@ -302,73 +294,72 @@ mod tests {
 
         let ft = FuturesTypes::Inverse;
         let p = 0.0;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 3.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 3.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 3.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 3.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.5);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.5);
         }
     }
 
@@ -377,7 +368,6 @@ mod tests {
         if let Err(_) = pretty_env_logger::try_init() {}
 
         let ft = FuturesTypes::Inverse;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
@@ -386,66 +376,66 @@ mod tests {
             let p = l * 100.0;
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 3.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 3.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
         }
     }
 
@@ -454,7 +444,6 @@ mod tests {
         if let Err(_) = pretty_env_logger::try_init() {}
 
         let ft = FuturesTypes::Inverse;
-        let p_ep = 100.0;
         let f_m = 0.0;
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
@@ -463,66 +452,66 @@ mod tests {
             let p = -l * 100.0;
 
             let orders = vec![];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 0.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 0.0);
 
             let orders = vec![Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap()];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 2.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 2.0);
 
             let orders = vec![
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 3.0);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 3.0);
 
             let orders = vec![
                 Order::limit(Side::Buy, 100.0, 100.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap(),
                 Order::limit(Side::Sell, 100.0, 100.0 * l).unwrap(),
             ];
-            assert_eq!(order_margin(orders.iter(), p, p_ep, ft, l, f_m), 1.5);
+            assert_eq!(order_margin(orders.iter(), p, ft, l, f_m), 1.5);
         }
     }
 }
